Open Source Telephony
 help / color / mirror / Atom feed
* [PATCH] udevng: fix tty subsystem device on usb bus detection
@ 2024-05-30  7:15 Ivaylo Dimitrov
  2024-05-30  7:21 ` Ivaylo Dimitrov
  0 siblings, 1 reply; 2+ messages in thread
From: Ivaylo Dimitrov @ 2024-05-30  7:15 UTC (permalink / raw)
  To: ofono; +Cc: denkenz, Ivaylo Dimitrov

Fixes: cdd58360140a ("udevng: Add mhi subsystem detection")
---
 plugins/udevng.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/plugins/udevng.c b/plugins/udevng.c
index d3ce3d5..891412d 100644
--- a/plugins/udevng.c
+++ b/plugins/udevng.c
@@ -2509,8 +2509,8 @@ static void check_device(struct udev_device *device)
 	const char *subsystem = udev_device_get_subsystem(device);
 	const char *bus = udev_device_get_property_value(device, "ID_BUS");
 
-	if (l_streq0(subsystem, "net")) {
-		/* Handle USB-connected network devices in check_usb_device */
+	if (l_streq0(subsystem, "net") || l_streq0(subsystem, "tty")) {
+		/* Handle USB-connected net/tty devices in check_usb_device */
 		if (l_streq0(bus, "usb"))
 			check_usb_device(device);
 		else
-- 
1.9.1


^ permalink raw reply related	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2024-05-30  7:21 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-05-30  7:15 [PATCH] udevng: fix tty subsystem device on usb bus detection Ivaylo Dimitrov
2024-05-30  7:21 ` Ivaylo Dimitrov

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox